@@ -19,7 +19,7 @@ extern SEXP get_supported_tags_C(SEXP);
 extern SEXP match_pillar_to_row_3_C(SEXP, SEXP);
 extern SEXP read_tags_C(SEXP, SEXP);
 extern SEXP read_tif_C(SEXP, SEXP);
-extern SEXP write_tif_C(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP write_tif_C(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"count_directories_C",    (DL_FUNC) &count_directories_C,    1},
@@ -31,7 +31,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"match_pillar_to_row_3_C", (DL_FUNC) &match_pillar_to_row_3_C, 2},
     {"read_tags_C",             (DL_FUNC) &read_tags_C,             2},
     {"read_tif_C",              (DL_FUNC) &read_tif_C,              2},
-    {"write_tif_C",             (DL_FUNC) &write_tif_C,             15},
+    {"write_tif_C",             (DL_FUNC) &write_tif_C,             16},
     {NULL, NULL, 0}
 };
 
